# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.106.0-v202602191122-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ModelV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'derived_features': 'list[DerivedFeatureV1]',
        'description': 'str',
        'id': 'str',
        'input_features': 'list[InputFeatureV1]',
        'name': 'str',
        'scoped_to': 'str'
    }

    attribute_map = {
        'derived_features': 'derivedFeatures',
        'description': 'description',
        'id': 'id',
        'input_features': 'inputFeatures',
        'name': 'name',
        'scoped_to': 'scopedTo'
    }

    def __init__(self, derived_features=None, description=None, id=None, input_features=None, name=None, scoped_to=None):
        """
        ModelV1 - a model defined in Swagger
        """

        self._derived_features = None
        self._description = None
        self._id = None
        self._input_features = None
        self._name = None
        self._scoped_to = None

        if derived_features is not None:
          self.derived_features = derived_features
        if description is not None:
          self.description = description
        if id is not None:
          self.id = id
        if input_features is not None:
          self.input_features = input_features
        if name is not None:
          self.name = name
        if scoped_to is not None:
          self.scoped_to = scoped_to

    @property
    def derived_features(self):
        """
        Gets the derived_features of this ModelV1.
        List of derived features for the model

        :return: The derived_features of this ModelV1.
        :rtype: list[DerivedFeatureV1]
        """
        return self._derived_features

    @derived_features.setter
    def derived_features(self, derived_features):
        """
        Sets the derived_features of this ModelV1.
        List of derived features for the model

        :param derived_features: The derived_features of this ModelV1.
        :type: list[DerivedFeatureV1]
        """

        self._derived_features = derived_features

    @property
    def description(self):
        """
        Gets the description of this ModelV1.
        Description of the model

        :return: The description of this ModelV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ModelV1.
        Description of the model

        :param description: The description of this ModelV1.
        :type: str
        """

        self._description = description

    @property
    def id(self):
        """
        Gets the id of this ModelV1.
        Unique identifier of the model, omit on create

        :return: The id of this ModelV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ModelV1.
        Unique identifier of the model, omit on create

        :param id: The id of this ModelV1.
        :type: str
        """

        self._id = id

    @property
    def input_features(self):
        """
        Gets the input_features of this ModelV1.
        List of input features for the model

        :return: The input_features of this ModelV1.
        :rtype: list[InputFeatureV1]
        """
        return self._input_features

    @input_features.setter
    def input_features(self, input_features):
        """
        Sets the input_features of this ModelV1.
        List of input features for the model

        :param input_features: The input_features of this ModelV1.
        :type: list[InputFeatureV1]
        """

        self._input_features = input_features

    @property
    def name(self):
        """
        Gets the name of this ModelV1.
        Name of the model

        :return: The name of this ModelV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ModelV1.
        Name of the model

        :param name: The name of this ModelV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this ModelV1.
        The ID of the workbook to which the model will be scoped. If not provided, the model will have a global scope

        :return: The scoped_to of this ModelV1.
        :rtype: str
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this ModelV1.
        The ID of the workbook to which the model will be scoped. If not provided, the model will have a global scope

        :param scoped_to: The scoped_to of this ModelV1.
        :type: str
        """

        self._scoped_to = scoped_to

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ModelV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
